<?php

add_editor_style();
add_theme_support('automatic-feed-links');

load_theme_textdomain('delicacy', TEMPLATEPATH.'/languages' );

$locale = get_locale();
$locale_file = TEMPLATEPATH."/languages/$locale.php";
if(is_readable($locale_file)) require_once($locale_file);

// Image thumbnails
if (function_exists('add_theme_support')) {
	add_theme_support('post-thumbnails');
	set_post_thumbnail_size(136, 136, true);
	add_image_size('side-thumb', 80, 70, true);
	add_image_size('related-thumb', 100, 100, true);
	add_image_size('nivo-thumb', 588, 289, true); // nivo slider image
}


// Clean up the <head>
function removeHeadLinks()
{
	remove_action('wp_head', 'rsd_link');
	remove_action('wp_head', 'wlwmanifest_link');
}

add_action('init', 'removeHeadLinks');
remove_action('wp_head', 'wp_generator');


// Register Menu
add_action('init', 'register_delicacy_menu');

function register_delicacy_menu()
{
	register_nav_menu('primary-menu', __('Delicacy Main Menu','delicacy'));
}

// Excerpt config
function new_excerpt($more)
{
	global $post;
	return '... <a href="' . get_permalink($post->ID) . '">'.__('Continue reading', 'delicacy').' &raquo;</a>';
}

add_filter('excerpt_more', 'new_excerpt');

function new_excerpt_length($length)
{
	global $post;
	return 20;
}

// Content width
global $content_width;
if(!isset($content_width)) $content_width = 600;

add_filter('excerpt_length', 'new_excerpt_length');

// JavaScript & CSS

// Load jQuery

function js_scripts()
{
	if (!is_admin()) {
		wp_deregister_script('jquery');
		wp_register_script('jquery', ("http://ajax.googleapis.com/ajax/libs/jquery/1.4.1/jquery.min.js"), false);
		wp_enqueue_script('jquery');
	}
	if (is_home()){
	wp_register_script('nivoslider', get_template_directory_uri() . '/js/nivo-slider/jquery.nivo.slider.pack.js');
	wp_enqueue_script('nivoslider');	
	}
	wp_register_script('delicacy', get_template_directory_uri() . '/js/delicacy.js');
	wp_enqueue_script('delicacy');
	wp_register_script('sfmenu', get_template_directory_uri() . '/js/superfish.js');
	wp_enqueue_script('sfmenu');
}

add_action('wp_enqueue_scripts', 'js_scripts');

function css_files()
{
	wp_register_style('sfcss', get_template_directory_uri() . '/js/superfish.css');
	wp_enqueue_style('sfcss');
	if (is_home()){
	wp_register_style('nivocss', get_template_directory_uri() . '/js/nivo-slider/nivo-slider.css');
	wp_enqueue_style('nivocss');
	}
}


add_action('wp_print_styles', 'css_files');

// Custom backgrounds support
define('BACKGROUND_IMAGE', 'wp-content/themes/Delicacy/images/bg/bg01.png');
define('BACKGROUND_COLOR', 'f8f8f8');
add_custom_background();

// Copyright function
function copy_date() {

	global $wpdb;
	$daty = $wpdb->get_results("SELECT YEAR(min(post_date)) as 'start', YEAR(now()) as 'end' from wp_posts where post_status = 'publish'");

	if ($daty[0]->start != $daty[0]->end){
		$copy = "&copy; ".$daty[0]->start." - ".$daty[0]->end;
	}else{
		$copy = "&copy; ".$daty[0]->start;
	}
	return $copy;
}

// Custom meta boxes
/**
 * Prepare admin interface
 */
add_action('admin_init','Delicacy_admin_init');
function Delicacy_admin_init(){
	wp_enqueue_style('Delicacy_admin', get_template_directory_uri(). '/admin.css');
	wp_enqueue_script('tiny_mce');
}

require dirname(__FILE__).'/meta-box/meta-box-3.2.2.class.php';

class Delicacy_Meta_Box extends RW_Meta_Box {
	function check_field_wysiwyg() {
		if ($this->has_field('wysiwyg') && self::is_edit_page()) {
			add_action('admin_print_footer_scripts', 'wp_tiny_mce', 25);
		}
	}


	function show_field_wysiwyg($field, $meta) {
		$this->show_field_begin($field, $meta);
		echo "<textarea class='rw-wysiwyg foooobar large-text' name='{$field['id']}' id='{$field['id']}' cols='60' rows='10'>$meta</textarea>";
		$this->show_field_end($field, $meta);
		wp_tiny_mce( true, // true makes the editor "teeny"
			array(
				"editor_selector" => "rw-wysiwyg"
			)
		);
	}
}

new Delicacy_Meta_Box(array(
	'id' => 'Delicacy',							// meta box id, unique per meta box
	'title' => __('Culinary recipe', 'delicacy'),	// meta box title
	'pages' => array('post',),					// post types, accept custom post types as well, default is array('post'); optional
	'context' => 'normal',						// where the meta box appear: normal (default), advanced, side; optional
	'priority' => 'high',						// order of meta box: high (default), low; optional

	'fields' => array(							// list of meta fields
		array(
			'name' => __('Servings', 'delicacy'),
			'desc' => __('Enter the number of servings eg. "4"', 'delicacy'),
			'id' => 'Delicacy_servings',
			'type' => 'text',
		),

		array(
			'name' => __('Prep time', 'delicacy'),
			'desc' => __('How long does it take to prep (without cooking time, eg. 20 min.)', 'delicacy'),
			'id' => 'Delicacy_prep_time',
			'type' => 'text',
			'std' => '',
		),

		array(
			'name' => __('Cooking time', 'delicacy'),
			'desc' => __('Toal time of cooking, baking etc.', 'delicacy'),
			'id' => 'Delicacy_cook_time',
			'type' => 'text',
			'std' => '',
		),

		array(
			'name' => __('Difficulty', 'delicacy'),
//			'desc' => '',
			'id' => 'Delicacy_difficulty',
			'type' => 'select',
			'options' => array(
				1 => __('easy', 'delicacy'),
				2 => __('medium', 'delicacy'),
				3 => __('hard', 'delicacy')
			),
			'std' => '',
		),

		array(
			'name' => __('Ingredients', 'delicacy'),
			'desc' => __('Enter all the ingredients. IMPORTANT: Seperate the ingredients with a single line break.', 'delicacy'),
			'id' => 'Delicacy_ingredients',
			'type' => 'textarea',
			'std' => '',
		),
		array(
			'name' => __('Directions', 'delicacy'),
			'id' => 'Delicacy_recipe',
			'type' => 'wysiwyg',
			'std' => '',
		),
/*		array(
			'name' => 'Zdjęcia z przygotowania potrawy',
			'desc' => 'Screenshots of problems, warnings, etc.',
			'id' => 'screenshot',
			'type' => 'image'						// image upload
		)*/

	),
));


// Comments
function delicacy_comments($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; ?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">

		<div class="the-comment">

			<?php echo get_avatar($comment,$size='60'); ?>

			<div class="comment-box">

				<div class="comment-author">
					<strong><?php echo get_comment_author_link() ?></strong>
					<small><?php printf(__('%1$s at %2$s','delicacy'), get_comment_date(),  get_comment_time()) ?><?php edit_comment_link(__('Edit','delicacy'),'  ','') ?> <?php comment_reply_link(array_merge( $args, array('reply_text' => 'Reply', 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?></small>
				</div>

				<div class="comment-text">
					<?php if ($comment->comment_approved == '0') : ?>
					<em><?php _e('Your comment awaits moderation.','delicacy') ?></em>
					<br />
					<?php endif; ?>
					<?php comment_text() ?>
				</div>

			</div>

		</div>

<?php }



// Register widgets
if ( function_exists('register_sidebar') ) {
	register_sidebar(array(
		'name' => 'Right Sidebar',
		'before_widget' => '<div class="widget">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name' => 'Header Widget',
		'before_widget' => '',
		'after_widget' => '',
		'before_title' => '',
		'after_title' => '',
	));
}

// Include functions
include("admin/widgets/about-widget.php");
include("admin/widgets/recent-posts-widget.php");
include("admin/widgets/archives-widget.php");
include("admin/widgets/social-widget.php");
include("admin/widgets/seasonal-recipes-widget.php");



if ( !function_exists( 'optionsframework_init' ) ) {

/*-----------------------------------------------------------------------------------*/
/* Options Framework Theme
/*-----------------------------------------------------------------------------------*/

/* Set the file path based on whether the Options Framework Theme is a parent theme or child theme */

if ( STYLESHEETPATH == TEMPLATEPATH ) {
	define('OPTIONS_FRAMEWORK_URL', TEMPLATEPATH . '/admin/');
	define('OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/admin/');
} else {
	define('OPTIONS_FRAMEWORK_URL', STYLESHEETPATH . '/admin/');
	define('OPTIONS_FRAMEWORK_DIRECTORY', get_stylesheet_directory_uri() . '/admin/');
}

require_once (OPTIONS_FRAMEWORK_URL . 'options-framework.php');

}

/*
 * This is an example of how to add custom scripts to the options panel.
 * This one shows/hides the an option when a checkbox is clicked.
 */

add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function() {

	jQuery('#example_showhidden').click(function() {
  		jQuery('#section-example_text_hidden').fadeToggle(400);
	});

	if (jQuery('#example_showhidden:checked').val() !== undefined) {
		jQuery('#section-example_text_hidden').show();
	}

});
</script>

<?php
}
